/***************************************************************************
 *   Copyright (C) 2007-2015 by Helge Kortendieck  alan@kasmithee.de       *
 *   abouthelp.cpp  -  show about or help dialog                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
 ***************************************************************************/
#include "abouthelp.h"

aboutHelp::aboutHelp( QDialog* parent )
        : QDialog( parent )
{
	uih.setupUi(&wHelp);
	connect(uih.pB_Close, SIGNAL(clicked()), this, SLOT(closeDlg()));
}

aboutHelp::~aboutHelp()
{
}

void aboutHelp::showAbout()					// show about dialog, type 1
{
	iTyp = 1;
	iWidth = 550;
	iHeight = 260;
	sTitle = tr("about siimvi");
	showDlg();
}

void aboutHelp::showHelp()					// show help dialog, type 2
{
	iTyp = 2;
	sTitle = tr("siimvi - help");
	showDlg();
}

void aboutHelp::showMsg(const QString& sD, const QString& sD2)	// show error dialog, type 3
{
	sTitle = sD;
	sText = sD2;
	iTyp = 3;
	iWidth = 550;
	iHeight = 260;
	showDlg();
}

void aboutHelp::showDlg()					// show dialog: 1=about, 2=help, 3=Error
{
	if (wHelp.isVisible() == true) {
		wHelp.hide();
	}
	setText();
	if (iTyp == 1 or iTyp == 2) {
		uih.tb_Help->setHtml(sText);
	} else {
		uih.tb_Help->setPlainText(sText);		// for messages
	}
	wHelp.setWindowTitle(sTitle);
	if (iTyp == 2) {
		wHelp.showFullScreen();
	} else {
		wHelp.resize(iWidth, iHeight);
		qPos = QCursor::pos();
		iD = qPos.x() - iWidth;
		if(iD < 0) {
			iD = 0;
		}
		iD2 = qPos.y() - iHeight;
		if(iD2 < 0) {
			iD2 = 0;
		}
		wHelp.move(iD, iD2);
	}
	wHelp.show();
}

void aboutHelp::closeDlg()
{
	wHelp.hide();
	emit sigAhwHidden();
}

void aboutHelp::setText()					// set text to show: 1=About (html), 2=Help (html), 3=Error (txt)
{
	switch (iTyp) {
		case 1:									// about text (html)
			sText = tr("<html><body>"
				"siimvi - a simple image viewer based on Qt5.<br>"
				"Using ExifTool by Phil Harvey and exiv2 to get Exif information if available.<p>"
				"Version 1.0.0<br>"
				"(C) 2007-2016 by Helge Kortendieck, alan@kasmithee.de<p>"
				"This program is released under GPL2 or later."
				"</body></html>");
			break;
		case 2:									// help text (html)
			sText = tr("<html><body>"
				"<a name=""Top""><b>Table of content</b></a><br>"
				"<a href=""#Intro"">Introduction</a><br>"
				"<a href=""#Start"">Starting</a><br>"
				"<a href=""#Set"">Settings</a><br>"
				"<a href=""#Options"">Command line options</a><br>"
				"<a href=""#Examples"">Examples</a><br>"
				"<a href=""#Faq"">FAQ</a><br>"
				"<a href=""#Credits"">Credits</a><p>"

				"<hr>"
				"<a name=""Intro""><b><u>Introduction</u></b></a><p>"
				"siimvi is a simple image viewer with only a few settings.<br>"
				"It is designed for quick n dirty image viewing and not for image manipulation.<br>"
				"It is mouse centric. All functions can be easily accessed via the mouse, either directly, by clicking a mouse button, or via "
				"a small menu, activated by 'right-clicking' into the screen.<p>"

				"It always uses the full screen, either showing the image in original size (which may leave some parts of the image " 
				"out of the current view) or scaled to screen size.<br>"
				"If the image is larger than the screen in at least one dimension, X or Y, clicking on the left mouse button will toggle "
				"between these 2 modes. If an image larger than the screen is shown in it's original size, the cursor will switch from an "
				"arrow to a claw-hand to show that it is grabbed. In this mode the image can be moved 'under' the screen's view by moving the mouse.<br>"
				"Images smaller than the screen size will always be shown in their original size. Zooming is not supported.<p>"

				"siimvi does not come with a file dialog. The first image has to be provided as a command line option. When an image is "
				"shown, one can cycle between other images in it's directory with mouse wheel up or down. If more than 1 image was given "
				"on the command line (space separated), mouse wheel up or down will cycle between the given images instead.<p>"

				"siimvi supports exif information and can, if set in the settings dialog, auto-rotate images on opening.<p>"

				"At the lower right of the image the name and/or size of the image can be shown after load. What to show and the time the "
				"information is shown can be set in the settings dialog.<p>"
				"<a href=""#Top"">back to top</a><p>"

				"<hr>"
				"<a name=""Start""><b><u>Starting</u></b></a><p>"
				"Start siimvi together with at least one image filename or with more, space separated, image files.<br>"
				"Right-clicking into the image will pop up a small menu with which some settings can be adjusted.<br>"
				"Use the mouse wheel up/down to show any other supported images in the directory the original image is located.<p>"
				"<a href=""#Top"">back to top</a><p>"

				"<hr>"
				"<a name=""Set""><b><u>Settings</u></b></a><p>"
				"To access the settings dialog, right-click into the image and select 'Settings dialog' from the pop up menu "
				"(or hit the d-key while the menu is been showing).<p>"
				"The following settings can be defined:<p>"

				"<b>Open image fit-to-screen...</b><br>"
				"Shall the image be opened in original size (1:1) or fit-to-screen. If the checkbox is checked, images will be opened "
				"fit-to-screen. The default is unchecked, open images in their original size.<br>"
				"Beeing shown in original size might mean that the image does not fully fit onto the screen. "
				"If the image is larger than the screen, it can be moved under the viewable area with the mouse.<br>"
				"Beeing shown fit-to-screen means that an image larger then the screen size is scaled down but by retaining it's original proportion "
				"and can therefore, depending on the image geometry, lead to black borders on the left and right or top and bottom of the image. "
				"Imaged smaller than the screen will always be shown in their original size. Enlarging images is not supported.<br>"
				"This setting can be toggled at run time by clicking the left mouse button. The last toggled setting is retained until the program "
				"is closed. On next start up, the default set here will be used again.<p>"

				"<b>Show image name on load</b><br>"
				"Check this checkbox if the image name (full path and name) should be shown after the image was loaded. This can be combined "
				"with the image size (see next setting). The time to show and the font size can be adjusted as well, see the following settings.<br>"
				"This setting can be toggled via the menu or the n-key. The last toggled setting is contained until the program is closed. "
				"On next start up, the default set here will be used again.<br>"
				"<b>Show image size on load</b><br>"
				"Check this checkbox if the image size (XXXxYYY pixels) should be shown after the image was loaded. This can be combined "
				"with the image name (see previous setting). The time to show and the font size can be adjusted as well, see the following settings.<br>"
				"This setting can be toggled via the menu or the s-key. The last toggled setting is contained until the program is closed. "
				"On next start up, the default set here will be used again.<br>"
				"<b>Time to show image name and/or size</b><br>"
				"Define for how many seconds the image name and/or size shall be shown after the image was loaded.<br>"
				"<b>Font size of image name and/or size</b><br>"
				"Define the font size in points the image name and/or size are shown after the image was loaded.<p>"

				"<b>Auto-rotate on Exif info</b><br>"
				"Check this box if the image should be rotated according Exif information if found in image.<br>"
				"Exif information are written by digital cameras into a special area of the image file. Many cameras recognize the orientation "
				"the camera is held in when a picture is taken and write it into the image file. siimvi can use this information to auto-rotate "
				"an image on loading.<p>"

				"<b>Use this font size</b><br>"
				"Check this checkbox and set an appropriate font size if you want the image information to be shown in a different size as the system default. "
				"A reason could be to save some space on the screen as long as the info widget cannot be placed on a different monitor (a current Qt 4.5 restriction)<p>"
				"<a href=""#Top"">back to top</a><p>"

				"<hr>"
				"<a name=""Options""><b><u>Command line options</u></b></a><p>"
				"<b>path/filename</b><br>"
				"siimvi will open the image and if more than 1 image is available in this directory, one can cycle to these with the mouse wheel.<p>"
				"<b>space separated list with path/filenames</b><br>"
				"siimvi will open the first image and one can cycle to all given images with the mouse wheel.<p>"
				"<b>-v</b> or <b>--version</b><br>"
				"This will print the program's version information to standard out, the console.<p>"
				"<b>-h</b> or <b>--help</b><br>"
				"This will print a short help message to standard out, the console.<p>"
				"<a href=""#Top"">back to top</a><p>"

				"<hr>"
				"<a name=""Examples""><b><u>Examples</u></b></a><p>"
				"<b>siimvi /tmp/image</b><br>"
				"This will start the program and will show the image.<br>"
				"If more images exist in /tmp, one can cycle between them with mouse wheel up or down.<p>"
				"<b>siimvi /tmp/image1 /tmp/image2 /new_tmp/image3</b><br>"
				"This will start the program and will show image1 from /tmp.<br>"
				"With mouse wheel up or down one can now cycle between those 3 given images.<p>"
				"<b>Setting siimvi as the default image viewer in Thunar</b><br>"
				"1. open Thunar<br>"
				"2. select a directory with an image<br>"
				"3. right-click on an image<br>"
				"4. select 'open with'<br>"
				"5. select 'browse' or 'open with other application'<br>"
				"6. select siimvi, it should be found under: /usr/bin/siimvi<br>"
				"7. ensure, that the checkbox 'use as standard for this file type' is checked !<br>"
				"8. click 'OK' - done<br>"
				"These steps have to be repeated for each mime (file) type you want to set siimvi as the default application.<br>"
				"Note, that this was written using a german setting, so some of the above phrases could be slightly different in the actual english Thunar "
				"setting, but you got the idea, I hope.<p>"
				"<b>siimvi can be used as the default image viewer in claws-mail, too</b><br>"
				"1. in claws-mail right-click on an image attachement and select 'open with'<br>"
				"2. select siimvi, it should be found under: /usr/bin/siimvi<br>"
				"3. click 'OK' - done<br>"
				"claws-mail should remember to use siimvi as the default image viewer.<br>"
				"So next time, a simple right-click on the attachment (line with link to the image) and selecting 'open' should be enough.<p>"
				"<a href=""#Top"">back to top</a><p>"

				"<hr>"
				"<a name=""Faq""><b><u>FAQ</u></b></a><p>"
				"<b>There are no icons in the menu?</b><br>"
				"The menu icons are linked to the gnome icon theme. If this is not installed, there will be no icons in the menu. Future versions may fall back to a freedesktop.org standard theme (if there is anything like that).<p>"
				"<b>Memory usage is a bit high?</b><br>"
				"Right after loading an image internally into a QImage, a copy of this QImage is made to allow the possible save of the loaded image. Due to speed reasons, all image manipulation is done on the loaded QImage, which is only transferred to a QPixmap just before showing. So to allow a loaded image to be stored in it's original size and quality, it must be copied right after loading. This is a trade off of memory vs the often slower re-loading from the internet of the image for saving a copy. Take it as a program design solution for now. Usually the size of an image is not a great deal with todays computer RAM configuration and copying the image after loading internally from one QImage to another in RAM is very fast.<p>"
				"<a href=""#Top"">back to top</a><p>"

				"<hr>"
				"<a name=""Credits""><b><u>Credits</u></b></a><p>"
				"ExifTool by Phil Harvey is used to get Exif information if an Exif tag is embedded in the image, see http://owl.phy.queensu.ca/~phil/exiftool/ , (Oct. 2015).<br>"
				"Exiv2 is used to show rotated images correctly. See www.exif2.org (Oct. 2015).<p>"
				"Program icons are taken from the following sources:<br>"
				" - open icon library, version 10 Nov. 2009:<br>"
				" - - theme gnome, licence GPLv2:<br>"
				" - - - about.svg from actions/help-about.svg<br>"
				" - - - help.svg from actions/help-browser.svg<br>"
				" - - - rotate-left.svg from actions/object-rotate-left.svg<br>"
				" - - - rotate-right.svg from actions/object-rotate-right.svg<br>"
				" - - - save.svg from actions/document-save-2.svg<br>"
				" - - - show-fullscreen.svg from actions/zoom-fit-best-2.svg<br>"
				" - - - show-original.svg from actions/zoom-original-2.svg<br>"
				" - - theme gnome-Colors, licence GPLv2:<br>"
				" - - - exit.svg from actions/application-exit-3.svg<br>"
				" - - theme oxygen, licence CC-BY-SA 3.0 or LGPL:<br>"
				" - - - info.svg from actions/help-about-3.svg<br>"
				" - - - settings.svg from categories/preferences-system-4.svg<br>"
				" - - - widget-close.svg from actions/project-development-close.svg<br>"
				"The Program icon is a scaled down png from the KDE 3.x wallpaper soft-green.jpg.<p>"
				"Program and Documentation Copyright 2007-2016 Helge Kortendieck, alan@kasmithee.de .<p>"
				"siimvi is released under GPL2 or later.<p>"
				"<a href=""#Top"">back to top</a><p>"
				"</body></html>") ;
			break;
		case 3:                                     // error text (txt, ASCII)
      // sText is already set from parent (siimvi.cpp/h)
			break;
	}
}


#include "abouthelp.moc"
